from lxml import etree
from nacoma.hooks import Change
from nose.tools import *
import geomap_hook

xml = ''

def simple_fixture():
    global xml
    # xml file generated from Calle's dev system with monitor-geomap-2.3.5-p1.g2c62392.noarch
    locations_xml_file_contents = """<?xml version="1.0"?>
<locations><location id="4ea6945f16b523.77288910" point="59.4071252,17.93691530000001" label="op5 AB (HQ)" address="Norgegatan 2 164 32 Kista Sweden"/><location id="542d5608b215d7.56333622" point="56.072035471800866,7.4267578125" label="a host (Yes)" address="some addr" description="le desc"><host name="Yes"/></location><location id="542d5674b9c1d5.42906407" point="53.72271667491848,7.998046875" label="a hostgroup (A_FEW_DUMMIES)" address="add" description="desc"><hostgroup name="A_FEW_DUMMIES"/></location><location id="542d568ca8a3b0.40216209" point="53.48804553605622,10.458984375" label="a servicegroup (abrakadabra)" address="a" description="d"><servicegroup name="abrakadabra"/></location><location id="542d561cb4d981.21202471" point="55.80128097118045,10.810546875" label="a service (Yes;PING)" address="dat addrat" description="le desc"><service host="Yes" description="PING"/></location></locations>"""
    xml = etree.XML(locations_xml_file_contents)

@with_setup(simple_fixture)
def test_host_rename():
    eq_(xml.find(".//host").attrib['name'], 'Yes')
    host_change = "object_type='host'	object_id='3'	oldname='Yes'	newname='No'	username='mockeduser'	time='2014-10-02 15:38:38'	pre='host_name=Yes;'	post='host_name=No;'"
    geomap_hook.handle(xml, Change(host_change))
    eq_(xml.find(".//host").attrib['name'], 'No')
    eq_(xml.find(".//service").attrib['host'], 'No')

@with_setup(simple_fixture)
def test_service_on_host_rename():
    eq_(xml.find(".//service").attrib['host'], 'Yes')
    eq_(xml.find(".//service").attrib['description'], 'PING')
    service_change = "object_type='service'	object_id='271'	oldname='Yes;PING'	newname='Yes;shut it'	username='mockeduser'	time='2014-10-03 12:41:53'	pre='service_description=PING;'	post='service_description=shut it;'"
    geomap_hook.handle(xml, Change(service_change))
    eq_(xml.find(".//service").attrib['host'], 'Yes')
    eq_(xml.find(".//service").attrib['description'], 'shut it')

@with_setup(simple_fixture)
def test_hostgroup_rename():
    eq_(xml.find(".//hostgroup").attrib['name'], 'A_FEW_DUMMIES')
    hostgroup_change = "object_type='hostgroup'	object_id='2'	oldname='A_FEW_DUMMIES'	newname='SOME_DUMMIES'	username='mockeduser'	time='2014-10-03 15:21:41'	pre='hostgroup_name=A_FEW_DUMMIES'	post='hostgroup_name=SOME_DUMMIES;'"
    geomap_hook.handle(xml, Change(hostgroup_change))
    eq_(xml.find(".//hostgroup").attrib['name'], 'SOME_DUMMIES')

@with_setup(simple_fixture)
def test_servicegroup_rename():
    eq_(xml.find(".//servicegroup").attrib['name'], 'abrakadabra')
    servicegroup_change = "object_type='servicegroup'	object_id='1'	oldname='abrakadabra'	newname='simsalabim'	username='mockeduser'	time='2014-10-03 15:24:13'	pre='servicegroup_name=abrakadabra'	post='servicegroup_name=simsalabim;'"
    geomap_hook.handle(xml, Change(servicegroup_change))
    eq_(xml.find(".//servicegroup").attrib['name'], 'simsalabim')

@with_setup(simple_fixture)
def test_host_delete():
    eq_(xml.find(".//host").attrib['name'], 'Yes')
    host_change = "object_type='host'	object_id='3'	oldname='Yes'	newname='No'	username='mockeduser'	time='2014-10-02 15:38:38'	pre='host_name=Yes;'	post='host_name=No;'"
    geomap_hook.handle(xml, Change(host_change))
    eq_(xml.find(".//host").attrib['name'], 'No')
    eq_(xml.find(".//service").attrib['host'], 'No')

@with_setup(simple_fixture)
def test_service_on_host_delete():
    eq_(xml.find(".//service").attrib['host'], 'Yes')
    eq_(xml.find(".//service").attrib['description'], 'PING')
    service_change = "object_type='service'	object_id='271'	oldname='Yes;PING'	newname='Yes;shut it'	username='mockeduser'	time='2014-10-03 12:41:53'	pre='service_description=PING;'	post='service_description=shut it;'"
    geomap_hook.handle(xml, Change(service_change))
    eq_(xml.find(".//service").attrib['host'], 'Yes')
    eq_(xml.find(".//service").attrib['description'], 'shut it')

@with_setup(simple_fixture)
def test_hostgroup_delete():
    eq_(xml.find(".//hostgroup").attrib['name'], 'A_FEW_DUMMIES')
    hostgroup_change = "object_type='hostgroup'	object_id='2'	oldname='A_FEW_DUMMIES'	newname='SOME_DUMMIES'	username='mockeduser'	time='2014-10-03 15:21:41'	pre='hostgroup_name=A_FEW_DUMMIES'	post='hostgroup_name=SOME_DUMMIES;'"
    geomap_hook.handle(xml, Change(hostgroup_change))
    eq_(xml.find(".//hostgroup").attrib['name'], 'SOME_DUMMIES')

@with_setup(simple_fixture)
def test_servicegroup_delete():
    eq_(xml.find(".//servicegroup").attrib['name'], 'abrakadabra')
    servicegroup_change = "object_type='servicegroup'	object_id='1'	oldname='abrakadabra'	newname='simsalabim'	username='mockeduser'	time='2014-10-03 15:24:13'	pre='servicegroup_name=abrakadabra'	post='servicegroup_name=simsalabim;'"
    geomap_hook.handle(xml, Change(servicegroup_change))
    eq_(xml.find(".//servicegroup").attrib['name'], 'simsalabim')
